package com.ruoyi.system.service.impl;

import java.util.List;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.ProductMapper;
import com.ruoyi.system.domain.Product;
import com.ruoyi.system.service.IProductService;

/**
 * 产品基础信息表 服务实现
 *
 * @author ruoyi
 */
@Service
public class ProductServiceImpl implements IProductService
{
    @Autowired
    private ProductMapper productMapper;

    /**
     * 查询产品基础信息集合
     *
     * @param product 产品信息
     * @return 产品集合
     */
    @Override
    public List<Product> selectProductList(Product product)
    {
        return productMapper.selectProductList(product);
    }

    /**
     * 分页查询产品基础信息集合
     *
     * @param product 产品信息
     * @return 分页数据
     */
    @Override
    public TableDataInfo selectProductListByPage(Product product, Integer pageNum, Integer pageSize)
    {
        if (pageNum == null) pageNum = 1;
        if (pageSize == null) pageSize = 10;
        PageHelper.startPage(pageNum, pageSize);
        List<Product> list = productMapper.selectProductList(product);
        PageInfo<Product> pageInfo = new PageInfo<>(list);
        return new TableDataInfo(list, pageInfo.getTotal());
    }

    /**
     * 根据ID查询产品基础信息
     *
     * @param id 主键ID
     * @return 产品信息
     */
    @Override
    public Product selectProductById(String ProductId)
    {
        return productMapper.selectProductById(ProductId);
    }

    /**
     * 新增产品基础信息
     *
     * @param product 产品信息
     * @return 结果
     */
    @Override
    public int insertProduct(Product product)
    {
        return productMapper.insertProduct(product);
    }

    /**
     * 修改产品基础信息
     *
     * @param product 产品信息
     * @return 结果
     */
    @Override
    public int updateProduct(Product product)
    {
        return productMapper.updateProduct(product);
    }

    /**
     * 删除产品基础信息
     *
     * @param id 主键ID
     * @return 结果
     */
    @Override
    public int deleteProductById(String ProductId)
    {
        return productMapper.deleteProductById(ProductId);
    }

    @Override
    public Product selectProductId(Long id) {
        return productMapper.selectProductId(id);
    }

    /**
     * 批量删除产品基础信息
     *
     * @param ids 需要删除的主键ID数组
     * @return 结果
     */
    @Override
    public int deleteProductByIds(Long[] ids)
    {
        return productMapper.deleteProductByIds(ids);
    }
}